pub async fn update_version(
shared: SharedDescribe,
locked_machine_stats: Arc<RwLock<MachineStats>>,
) -> Result<()>Expand description
Async wrapper that can update the systemd version when passed a locked struct.
pub async fn update_version(
shared: SharedDescribe,
locked_machine_stats: Arc<RwLock<MachineStats>>,
) -> Result<()>Async wrapper that can update the systemd version when passed a locked struct.